@@ -8,7 +8,8 @@
 #'
 #' \emph{Why does my standard polynomial regression give different p-values and SEs than the RSA package? Shouldn't they be the same?} This is due to the robust standard errors employed in the RSA package. If you set \code{estimator="ML"} and \code{se="standard"}, you get p-values that are very close to the standard approach. (They might still not be identical because the standard regression approach usually uses an OLS estimator and RSA uses an ML estimator).
 #'
-#' You can also fit \strong{binary outcome variables} with a probit link function. For that purpose, the response variable has to be defined as "ordered", and the \code{lavaan} estimator changed to "WLSMV": \code{r1 <- RSA(Z.binary ~ X*Y, dat, ordered="Z.binary", estimator="WLSMV")} (for more details see the help file of the \code{\link{sem}} function in the \code{lavaan} package.). The results can also be plotted with probabilities on the z axis using the probit link function: \code{plot(r1, link="probit", zlim=c(0, 1), zlab="Probability")}. \code{lavaan} at the moment only supports a probit link function for binary outcomes, not a logit link.
+#' Experimental feature (use with caution!): You can also fit \strong{binary outcome variables} with a probit link function. For that purpose, the response variable has to be defined as "ordered", and the \code{lavaan} estimator changed to "WLSMV": \code{r1.binary <- RSA(z.binary~x*y, df, ordered="z.binary", estimator="WLSMV", model="full")} (for more details see the help file of the \code{\link{sem}} function in the \code{lavaan} package.). The results can also be plotted with probabilities on the z axis using the probit link function: \code{plot(r1.binary, link="probit", zlim=c(0, 1), zlab="Probability")}. For plotting, the binary outcome variable must be coded with 0 and 1 (not as a factor).
+#' \code{lavaan} at the moment only supports a probit link function for binary outcomes, not a logit link. Please be aware that this experimental feature can fit the full model, but most other functions (such as model comparisons) might break and errors might show up.
 #'
 #' @export
 #' @import lavaan
@@ -75,6 +76,8 @@
 #' 	z.add <- diff + 0.4*x + rnorm(n, 0, err)
 #' 	z.complex <- 0.4*x + - 0.2*x*y + + 0.1*x^2 - 0.03*y^2 + rnorm(n, 0, err)
 #' })
+#' df$z.binary <- as.numeric(df$z.sq < median(df$z.sq))
+#'
 #' \dontrun{
 #' r1 <- RSA(z.sq~x*y, df)
 #' summary(r1)
@@ -85,6 +88,15 @@
 #' getPar(r1, "coef")	# print model parameters including SE and CI
 #' RSA.ST(r1)	# get surface parameters
 #'
+#' # Example with binary outcome 
+#' (probit regression, see Details; Experimental and a dirty workaround!).
+#' # The standard summary output does not work; you have to access the full model directly:
+#' r1.binary <- RSA(z.binary~x*y, df, ordered="z.binary", estimator="WLSMV", 
+#'     model="full", se="standard")
+#' # --> ignore the warning
+#' summary(r1.binary$models[["full"]])
+#' plot(r1.binary, link="probit", zlim=c(0, 1), zlab="Probability")
+#' 
 #' # Motive congruency example
 #' data(motcon)
 #' r.m <- RSA(postVA~ePow*iPow, motcon)
@@ -146,6 +158,10 @@ RSA <- function(formula, data=NULL, center="none", scale="none", na.rm=FALSE,
 	# when boolean options are used for center/scale (as was necessary in earlier package versions), restore behavior of earlier versions
 	if(center==TRUE){center <- "variablewise"}
 	if(scale==TRUE){scale <- "variablewise"}
+	if (!center %in% c("none", "variablewise", "pooled")) {
+		warning('Parameter `center` must be one of c("none", "variablewise", "pooled"), or TRUE (which corresponds to "variablewise") or FALSE (which corresponds to "none"). Setting to "none".')
+		center <- "none"
+	}
 	
 	# "variablewise": standardization at respective variable means/SDs
 	
